@@ -1,4 +1,4 @@
-class AddInternalFooterToList < ActiveRecord::Migration
+class AddInternalFooterToList < ActiveRecord::Migration[4.2]
   def up
     if ! column_exists?(:lists, :internal_footer)
       add_column :lists, :internal_footer, :text, default: ''
