@@ -2,7 +2,7 @@ module Schleuder
   module Errors
     class KeyAdduidFailed < Base
       def initialize(errmsg)
-        super t('errors.key_adduid_failed', { errmsg: errmsg })
+        super t('errors.key_adduid_failed', errmsg: errmsg)
       end
     end
   end
