@@ -3,7 +3,7 @@ module Schleuder
     class MessageEmpty < Base
       def initialize(list)
         set_default_locale
-        super t('errors.message_empty', { request_address: list.request_address })
+        super t('errors.message_empty', request_address: list.request_address)
       end
     end
   end
