@@ -4,7 +4,7 @@ module Schleuder
       def initialize(list)
         set_default_locale
         allowed_size = list.max_message_size_kb
-        super t('errors.message_too_big', { allowed_size: allowed_size })
+        super t('errors.message_too_big', allowed_size: allowed_size)
       end
     end
   end
