@@ -1,7 +1,7 @@
 module Schleuder
   module Filters
     def self.receive_from_subscribed_emailaddresses_only(list, mail)
-      if list.receive_from_subscribed_emailaddresses_only? && list.subscriptions.where(email: mail.from.first).blank?
+      if list.receive_from_subscribed_emailaddresses_only? && list.subscriptions.where(email: mail.from.first.downcase).blank?
         list.logger.info 'Rejecting mail as not from subscribed address.'
         return Errors::MessageSenderNotSubscribed.new
       end
