@@ -375,7 +375,7 @@ module Schleuder
           
         rescue => exc
           msg = I18n.t('errors.delivery_error',
-                       { email: subscription.email, error: exc.to_s })
+                       email: subscription.email, error: exc.to_s)
           logger.error msg
           logger.error exc
         end
