@@ -4,12 +4,12 @@ module Schleuder
       error = setup_list(recipient)
       return error if error
 
-      logger.info "Parsing incoming email."
+      logger.info 'Parsing incoming email.'
 
       # is it valid utf-8?
       msg_scrubbed = false
       unless msg.valid_encoding?
-        logger.warn "Converting message due to invalid characters"
+        logger.warn 'Converting message due to invalid characters'
         detection = CharlockHolmes::EncodingDetector.detect(msg)
         begin
           msg = CharlockHolmes::Converter.convert(msg, detection[:encoding], 'UTF-8')
@@ -18,7 +18,7 @@ module Schleuder
           # so we scrub the invalid characters to be able to
           # at least parse the message somehow. Though this might
           # result in data loss.
-          logger.warn "Scrubbing message due to invalid characters"
+          logger.warn 'Scrubbing message due to invalid characters'
           msg = msg.scrub
           msg_scrubbed = true
         end
@@ -27,11 +27,17 @@ module Schleuder
       @mail = Mail.create_message_to_list(msg, recipient, list)
 
       if msg_scrubbed
-        @mail.add_pseudoheader(:note, I18n.t("pseudoheaders.scrubbed_message"))
+        @mail.add_pseudoheader(:note, I18n.t('pseudoheaders.scrubbed_message'))
       end
 
       error = run_filters('pre')
-      return error if error
+      if error
+        if bounce?(error, @mail)
+          return error
+        else
+          return nil
+        end
+      end
 
       begin
         # This decrypts, verifies, etc.
@@ -40,39 +46,46 @@ module Schleuder
       rescue GPGME::Error::BadPassphrase,
              GPGME::Error::DecryptFailed,
              GPGME::Error::NoData,
-             GPGME::Error::NoSecretKey
+             GPGME::Error::NoSecretKey,
+             GPGME::Error::Canceled
 
-        logger.warn "Decryption of incoming message failed."
+        logger.warn 'Decryption of incoming message failed.'
         return Errors::DecryptionFailed.new(list)
       end
 
       error = run_filters('post')
-      return error if error
+      if error
+        if bounce?(error, @mail)
+          return error
+        else
+          return nil
+        end
+      end
 
       if ! @mail.was_validly_signed?
-        logger.debug "Message was not validly signed, adding subject_prefix_in"
+        logger.debug 'Message was not validly signed, adding subject_prefix_in'
         @mail.add_subject_prefix_in!
       end
 
       if ! @mail.was_encrypted?
-        logger.debug "Message was not encrypted, skipping plugins"
+        logger.debug 'Message was not encrypted, skipping keyword-handlers'
       elsif @mail.was_validly_signed?
-        # Plugins
-        logger.debug "Message was encrypted and validly signed"
-        PluginRunners::ListPluginsRunner.run(list, @mail).compact
+        # run KeywordHandlers
+        logger.debug 'Message was encrypted and validly signed'
+        KeywordHandlersRunner.run(type: :list, list: list, mail: @mail).compact
       end
 
       # Don't send empty messages over the list.
       if @mail.empty?
-        logger.info "Message found empty, not sending it to list."
+        logger.info 'Message found empty, not sending it to list.'
         return Errors::MessageEmpty.new(@list)
       end
 
-      logger.debug "Adding subject_prefix"
+      logger.debug 'Adding subject_prefix'
       @mail.add_subject_prefix!
 
       # Subscriptions
-      logger.debug "Creating clean copy of message"
+      logger.debug 'Creating clean copy of message'
       copy = @mail.clean_copy(list.headers_to_meta.any?)
       list.send_to_subscriptions(copy, @mail)
       nil
@@ -84,18 +97,36 @@ module Schleuder
       @list
     end
 
-    def run_filters(filter_type)
-      error = filters_runner(filter_type).run(@mail)
-      if error
-        if list.bounces_notify_admins?
-          text = "#{I18n.t('.bounces_notify_admins')}\n\n#{error}"
-          # TODO: raw_source is mostly blank?
-          logger.notify_admin text, @mail.original_message, I18n.t('notice')
-        end
-        return error
+    def notify_admins(reason, original_message)
+      if list.bounces_notify_admins
+        list.logger.notify_admin reason, original_message, I18n.t('notice')
       end
     end
 
+    def bounce?(response, mail)
+      if list.bounces_drop_all
+        list.logger.debug 'Dropping bounce as configurated'
+        notify_admins(I18n.t('.bounces_drop_all'), mail.original_message)
+        return false
+      end
+
+      list.bounces_drop_on_headers.each do |key, value|
+        if mail[key].to_s.match(/#{value}/i)
+          list.logger.debug "Incoming message header key '#{key}' matches value '#{value}': dropping the bounce."
+          notify_admins(I18n.t('.bounces_drop_on_headers', key: key, value: value), mail.original_message)
+          return false
+        end
+      end
+
+      list.logger.debug 'Bouncing message'
+      notify_admins("#{I18n.t('.bounces_notify_admins')}\n\n#{response}", mail.original_message)
+      true
+    end
+
+    def run_filters(filter_type)
+      filters_runner(filter_type).run(@mail)
+    end
+
     def filters_runner(filter_type)
       if filter_type == 'pre'
         filters_runner_pre_decryption
@@ -105,10 +136,11 @@ module Schleuder
     end
 
     def filters_runner_pre_decryption
-      @filters_runner_pre_decryption ||= Filters::Runner.new(list,'pre')
+      @filters_runner_pre_decryption ||= Filters::Runner.new(list, 'pre')
     end
+
     def filters_runner_post_decryption
-      @filters_runner_post_decryption ||= Filters::Runner.new(list,'post')
+      @filters_runner_post_decryption ||= Filters::Runner.new(list, 'post')
     end
 
     def logger
