@@ -1,11 +1,11 @@
-require "spec_helper"
+require 'spec_helper'
 
-describe "user sends emails with different charsets" do
-  Dir["spec/fixtures/mails/charset_mails/*.eml"].each do |f|
-    it "works with #{File.basename(f,'.eml')}" do
+describe 'user sends emails with different charsets' do
+  Dir['spec/fixtures/mails/charset_mails/*.eml'].each do |f|
+    it "works with #{File.basename(f, '.eml')}" do
       start_smtp_daemon
       list = create(:list)
-      list.subscribe("admin@example.org", nil, true)
+      list.subscribe('admin@example.org', nil, true)
 
       # Clean any LANG from env as this is usually the case for MUAs
       # https://0xacab.org/schleuder/schleuder/issues/409
