@@ -49,6 +49,7 @@ describe Schleuder::List do
   it { is_expected.to respond_to :logfiles_to_keep }
   it { is_expected.to respond_to :set_reply_to_to_sender }
   it { is_expected.to respond_to :munge_from }
+  it { is_expected.to respond_to :key_auto_import_from_email }
 
   it 'is invalid when email is nil' do
     # Don't use factory here because we'd run into List.listdir expecting email to not be nil.
@@ -209,10 +210,10 @@ describe Schleuder::List do
       expect(Schleuder::List.configurable_attributes).to eq [
        :bounces_drop_all, :bounces_drop_on_headers, :bounces_notify_admins, :deliver_selfsent,
        :forward_all_incoming_to_admins, :headers_to_meta, :include_list_headers,
-       :include_openpgp_header, :internal_footer, :keep_msgid, :keywords_admin_notify, :keywords_admin_only,
-       :language, :log_level, :logfiles_to_keep, :max_message_size_kb, :munge_from, :openpgp_header_preference,
-       :public_footer, :receive_admin_only, :receive_authenticated_only, :receive_encrypted_only,
-       :receive_from_subscribed_emailaddresses_only, :receive_signed_only, :send_encrypted_only,
+       :include_openpgp_header, :internal_footer, :keep_msgid, :key_auto_import_from_email, :keywords_admin_notify,
+       :keywords_admin_only, :language, :log_level, :logfiles_to_keep, :max_message_size_kb, :munge_from,
+       :openpgp_header_preference, :public_footer, :receive_admin_only, :receive_authenticated_only,
+       :receive_encrypted_only, :receive_from_subscribed_emailaddresses_only, :receive_signed_only, :send_encrypted_only,
        :set_reply_to_to_sender, :subject_prefix, :subject_prefix_in, :subject_prefix_out,   
       ]
     end
@@ -434,21 +435,21 @@ describe Schleuder::List do
       list = create(:list)
       allow_any_instance_of(GPGME::Key).to receive(:trust).and_return(:revoked)
 
-      expect(list.check_keys).to match(/This key is revoked:\n0x59C71FB38AEE22E091C78259D06350440F759BD3 schleuder@example.org \d{4}-\d{2}-\d{2} \[revoked\]\n\n/)
+      expect(list.check_keys).to eql("This key is revoked:\n0x59C71FB38AEE22E091C78259D06350440F759BD3 schleuder@example.org 2016-12-06 [revoked]\n\n")
     end
 
     it 'adds a message if a key is disabled' do
       list = create(:list)
       allow_any_instance_of(GPGME::Key).to receive(:trust).and_return(:disabled)
 
-      expect(list.check_keys).to match(/This key is disabled:\n0x59C71FB38AEE22E091C78259D06350440F759BD3 schleuder@example.org \d{4}-\d{2}-\d{2} \[disabled\]\n\n/)
+      expect(list.check_keys).to eql("This key is disabled:\n0x59C71FB38AEE22E091C78259D06350440F759BD3 schleuder@example.org 2016-12-06 [disabled]\n\n")
     end
 
     it 'adds a message if a key is invalid' do
       list = create(:list)
       allow_any_instance_of(GPGME::Key).to receive(:trust).and_return(:invalid)
 
-      expect(list.check_keys).to match(/This key is invalid:\n0x59C71FB38AEE22E091C78259D06350440F759BD3 schleuder@example.org \d{4}-\d{2}-\d{2} \[invalid\]\n\n/)
+      expect(list.check_keys).to eql("This key is invalid:\n0x59C71FB38AEE22E091C78259D06350440F759BD3 schleuder@example.org 2016-12-06 [invalid]\n\n")
     end
   end
 
@@ -510,56 +511,56 @@ describe Schleuder::List do
 
   context '#fetch_keys' do
     it 'fetches one key by fingerprint' do
+      resp = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/expired_key_extended.txt'))
+      Typhoeus.stub(/by-fingerprint\/98769E8A1091F36BD88403ECF71A3F8412D83889/).and_return(resp)
+       
       list = create(:list)
       list.subscribe('admin@example.org', nil, true)
-      output = ''
 
-      with_sks_mock(list.listdir) do
-        output = list.fetch_keys('98769E8A1091F36BD88403ECF71A3F8412D83889')
-      end
+      output = list.fetch_keys('98769E8A1091F36BD88403ECF71A3F8412D83889')
 
-      expect(output).to match(/This key was fetched \(new key\):\n0x98769E8A1091F36BD88403ECF71A3F8412D83889 bla@foo \d{4}-\d{2}-\d{2} \[expired: \d{4}-\d{2}-\d{2}\]/)
+      expect(output).to eql("This key was fetched (new key):\n0x98769E8A1091F36BD88403ECF71A3F8412D83889 bla@foo 2010-08-13 [expired: 2017-01-20]\n")
 
       teardown_list_and_mailer(list)
     end
 
     it 'fetches one key by URL' do
+      resp = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/expired_key_extended.txt'))
+      Typhoeus.stub(/keys\/example.asc/).and_return(resp)
+
       list = create(:list)
       list.subscribe('admin@example.org', nil, true)
-      output = ''
 
-      with_sks_mock(list.listdir) do |baseurl|
-        output = list.fetch_keys("#{baseurl}/keys/example.asc")
-      end
+      output = list.fetch_keys('http://somehost/keys/example.asc')
 
-      expect(output).to match(/This key was fetched \(new key\):\n0x98769E8A1091F36BD88403ECF71A3F8412D83889 bla@foo \d{4}-\d{2}-\d{2} \[expired: \d{4}-\d{2}-\d{2}\]/)
+      expect(output).to eql("This key was fetched (new key):\n0x98769E8A1091F36BD88403ECF71A3F8412D83889 bla@foo 2010-08-13 [expired: 2017-01-20]\n")
 
       teardown_list_and_mailer(list)
     end
 
     it 'fetches one key by email address' do
+      resp = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/expired_key_extended.txt'))
+      Typhoeus.stub(/by-email\/admin%40example.org/).and_return(resp)
+
       list = create(:list)
       list.subscribe('admin@example.org', nil, true)
-      output = ''
 
-      with_sks_mock(list.listdir) do
-        output = list.fetch_keys('admin@example.org')
-      end
+      output = list.fetch_keys('admin@example.org')
 
-      expect(output).to match(/This key was fetched \(new key\):\n0x98769E8A1091F36BD88403ECF71A3F8412D83889 bla@foo \d{4}-\d{2}-\d{2} \[expired: \d{4}-\d{2}-\d{2}\]/)
+      expect(output).to eql("This key was fetched (new key):\n0x98769E8A1091F36BD88403ECF71A3F8412D83889 bla@foo 2010-08-13 [expired: 2017-01-20]\n")
 
       teardown_list_and_mailer(list)
     end
 
     it 'does not import non-self-signatures' do
+      resp = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/openpgp-keys/public-key-with-third-party-signature.txt'))
+      Typhoeus.stub(/by-fingerprint\/87E65ED2081AE3D16BE4F0A5EBDBE899251F2412/).and_return(resp)
+
       list = create(:list)
       list.delete_key('87E65ED2081AE3D16BE4F0A5EBDBE899251F2412')
       list.subscribe('admin@example.org', nil, true)
-      output = ''
 
-      with_sks_mock(list.listdir) do
-        output = list.fetch_keys('87E65ED2081AE3D16BE4F0A5EBDBE899251F2412')
-      end
+      output = list.fetch_keys('87E65ED2081AE3D16BE4F0A5EBDBE899251F2412')
 
       # GPGME apparently does not show signatures correctly in some cases, so we better use gpgcli.
       signature_output = list.gpg.class.gpgcli(['--list-sigs', '87E65ED2081AE3D16BE4F0A5EBDBE899251F2412'])[1].grep(/0F759BD3.*schleuder@example.org/)
@@ -856,6 +857,28 @@ describe Schleuder::List do
 
       teardown_list_and_mailer(list)
     end
+  
+    it 'sends the message to subscribers if deliver_selfsent is set to false' do
+      list = create(:list, send_encrypted_only: false, deliver_selfsent: false)
+      sub, msgs = list.subscribe('admin@example.org', nil, true)
+      sub, msgs = list.subscribe('user1@example.org', nil)
+      mail = Mail.new
+      mail.to = list.email
+      mail.from = 'something@localhost'
+      mail.subject = 'Something'
+      mail.body = 'Some content'
+
+      Schleuder::Runner.new().run(mail.to_s, list.email)
+      messages = Mail::TestMailer.deliveries
+      recipients = messages.map { |m| m.to.first }.sort
+
+      expect(messages.size).to be(2)
+      expect(recipients).to eql(['admin@example.org', 'user1@example.org'])
+      expect(messages.first.parts.first.parts.last.body.to_s).to eql('Some content')
+      expect(messages.last.parts.first.parts.last.body.to_s).to eql('Some content')
+      expect(messages.first.subject).to eql('Something')
+      expect(messages.last.subject).to eql('Something')
+    end
   end
 
   describe '#set_reply_to_to_sender' do
@@ -1003,4 +1026,59 @@ describe Schleuder::List do
     end
   end
 
+  context '#refresh_keys' do
+    it 'updates keys from the keyserver' do
+      resp1 = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/default_list_key.txt'))
+      Typhoeus.stub(/by-fingerprint\/59C71FB38AEE22E091C78259D06350440F759BD3/).and_return(resp1)
+      resp2 = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/olduid_key_with_newuid.txt'))
+      Typhoeus.stub(/by-fingerprint\/6EE51D78FD0B33DE65CCF69D2104E20E20889F66/).and_return(resp2)
+      resp3 = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/expired_key_extended.txt'))
+      Typhoeus.stub(/by-fingerprint\/98769E8A1091F36BD88403ECF71A3F8412D83889/).and_return(resp3)
+
+      list = create(:list)
+      list.subscribe('admin@example.org', nil, true)
+      list.import_key(File.read('spec/fixtures/expired_key.txt'))
+      list.import_key(File.read('spec/fixtures/olduid_key.txt'))
+
+      res = list.refresh_keys
+
+      expect(res).to match(/This key was updated \(new signatures\):\n0x98769E8A1091F36BD88403ECF71A3F8412D83889 bla@foo \d{4}-\d{2}-\d{2} \[expired: \d{4}-\d{2}-\d{2}\]/)
+      expect(res).to match(/This key was updated \(new user-IDs and new signatures\):\n0x6EE51D78FD0B33DE65CCF69D2104E20E20889F66 new@example.org \d{4}-\d{2}-\d{2}/)
+    end
+    
+    it 'reports errors from refreshing keys' do
+      resp = Typhoeus::Response.new(code: 503, body: 'Internal server error')
+      Typhoeus.stub(/by-fingerprint/).and_return(resp)
+      Typhoeus.stub(/search=/).and_return(resp)
+
+      list = create(:list)
+      list.subscribe('admin@example.org', nil, true)
+      list.import_key(File.read('spec/fixtures/expired_key.txt'))
+
+      res = list.refresh_keys
+
+      expect(res).to match("Error while fetching data from the internet: Internal server error\nError while fetching data from the internet: Internal server error")
+    end
+
+    it 'does not import non-self-signatures' do
+      resp1 = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/openpgp-keys/public-key-with-third-party-signature.txt'))
+      Typhoeus.stub(/by-fingerprint\/87E65ED2081AE3D16BE4F0A5EBDBE899251F2412/).and_return(resp1)
+      resp2 = Typhoeus::Response.new(code: 200, body: File.read('spec/fixtures/default_list_key.txt'))
+      Typhoeus.stub(/by-fingerprint\/59C71FB38AEE22E091C78259D06350440F759BD3/).and_return(resp2)
+      
+      list = create(:list)
+      list.delete_key('87E65ED2081AE3D16BE4F0A5EBDBE899251F2412')
+      list.subscribe('admin@example.org', nil, true)
+      list.import_key(File.read('spec/fixtures/bla_foo_key.txt'))
+
+      res = list.refresh_keys
+
+      # GPGME apparently does not show signatures correctly in some cases, so we better use gpgcli.
+      signature_output = list.gpg.class.gpgcli(['--list-sigs', '87E65ED2081AE3D16BE4F0A5EBDBE899251F2412'])[1].grep(/0F759BD3.*schleuder@example.org/)
+
+      expect(res).to be_empty
+      expect(signature_output).to be_empty
+    end
+
+  end
 end
